cone.ugm.browser
================

Load configuration::

    >>> import cone.app.browser.login
    
    >>> import cone.ugm.browser.actions
    >>> import cone.ugm.browser.columns
    >>> import cone.ugm.browser.group
    >>> import cone.ugm.browser.groups
    >>> import cone.ugm.browser.root
    >>> import cone.ugm.browser.settings
    >>> import cone.ugm.browser.user
    >>> import cone.ugm.browser.users
    
    